@@ -11,3 +11,10 @@ from .empirical_formula import EmpiricalFormula
 from .nominal_composition import NominalComposition
 from .inchi_value import InChI
 from .smiles_value import Smiles
+
+__all__ = ["NominalReal", "NormalReal", "UniformReal",
+           "NominalInteger", "UniformInteger",
+           "NominalCategorical", "DiscreteCategorical",
+           "NominalComposition", "EmpiricalFormula",
+           "InChI", "Smiles"
+           ]
